<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR" sourcelanguage="en_US">
<context>
    <name>AboutBox</name>
    <message>
        <source>About FMIT...</source>
        <translation>Σχετικά με το FMIT...</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>FMIT</source>
        <translation>FMIT</translation>
    </message>
    <message>
        <source>&lt;version&gt;</source>
        <translation>&lt;έκδοση&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Μνείες</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Τα περισσότερα λογισμικά ανοιχτού κώδικα θα ήταν ακατόρθωτα χωρίς τις έμμεσες συνεισφορές που παρέχονται μέσω των βιβλιοθηκών. Έτσι, μεγάλα ευχαριστώ στους ακόλουθους geeks:&lt;br /&gt;&lt;br /&gt;- dsboger για τις τόσο πολλές μικρές και χρήσιμες αλλαγές, ενημερώσεις, πακετάρισμα, κλπ.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars για τις κλίμακες συντονισμού&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen για θα θέματα του JACK&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson για την ιδέα του microtonal module&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling για τις κλίμακες σε cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro για την βοήθεια του να μπορέσει το FMIT να λειτουργήσει κάτω από Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Ρωσσικά), skarmoutsosv (Ελληνικά), Pindaro and dsboger (Πορτογαλικά και Πορτογαλικά Βραζιλίας), Florian Maier (Γερμανικά).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; για το Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team για την βιβλιοθήκη GUI.&lt;br /&gt;&lt;br /&gt;Οποιαδήποτε συνεισφορά οποιουδήποτε είδους είναι καλοδεχούμενη!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigForm</name>
    <message>
        <source>Sampling rate</source>
        <translation>Ρυθμός δειγματολειψίας</translation>
    </message>
    <message>
        <source>set to max</source>
        <translation>ορισμός στο μέγιστο</translation>
    </message>
    <message>
        <source>Sound Analysis</source>
        <translation>Ανάλυση ήχου</translation>
    </message>
    <message>
        <source>Tonality</source>
        <translation type="vanished">Τονικότητα</translation>
    </message>
    <message>
        <source>Latency</source>
        <translation>Υστέρηση</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Εντάξει</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Άκυρο</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <source>Start in full-screen</source>
        <translation>Εκκίνηση σε πλήρη οθόνη</translation>
    </message>
    <message>
        <source>Volume threshold</source>
        <translation>Όριο έντασης</translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation>Χρόνος ανανέωσης</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Όνομα πελάτη</translation>
    </message>
    <message>
        <source>fmit</source>
        <translation>fmit</translation>
    </message>
    <message>
        <source>PortAudio</source>
        <translation>PortAudio</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Όνομα συσκευής</translation>
    </message>
    <message>
        <source>default</source>
        <translation>προεπιλογή</translation>
    </message>
    <message>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <source>/dev/dsp</source>
        <translation>/dev/dsp</translation>
    </message>
    <message>
        <source>Auto detect now</source>
        <translation>Αυτόματη ανίχνευση τώρα</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Αλγόριθμος</translation>
    </message>
    <message>
        <source>Quantizer</source>
        <translation>Quantizer</translation>
    </message>
    <message>
        <source>Frequency refinement</source>
        <translation>Βελτίωση συχνότητας</translation>
    </message>
    <message>
        <source>Maximum number of harmonics</source>
        <translation>Μέγιστος αριθμός αρμονικών</translation>
    </message>
    <message>
        <source>Maximum number of periods</source>
        <translation>Μέγιστος αριθμός περιόδων</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <source>Tuning scale</source>
        <translation>Κλίμακα συντονισμού</translation>
    </message>
    <message>
        <source>Werckmeister III</source>
        <translation></translation>
    </message>
    <message>
        <source>Kirnberger III</source>
        <translation></translation>
    </message>
    <message>
        <source>Meantone (1/4)</source>
        <translation>Μεσοτονικό (1/4)</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin note names:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="vanished">Χρήση αγγλο-σαξονικών ή λατινικών ονομάτων για τις νότες.
Αγγλοσαξονικά: C D E F G A B
Λατινικά: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <source>Note names</source>
        <translation>Ονόματα για τις νότες</translation>
    </message>
    <message>
        <source>Anglo-Saxon</source>
        <translation>Αγγλοσαξονικά</translation>
    </message>
    <message>
        <source>Latin</source>
        <translation>Λατινικά</translation>
    </message>
    <message>
        <source>Capture System</source>
        <translation>Σύστημα σύλληψης</translation>
    </message>
    <message>
        <source>Auto-detect an available capture system at startup</source>
        <translation>Αυτόματη ανίχνευση διαθέσιμου συστήματος σύλληψης κατά την εκκίνηση</translation>
    </message>
    <message>
        <source>JACK</source>
        <translation></translation>
    </message>
    <message>
        <source>Sampling rate of the JACK server</source>
        <translation>Ρυθμός δειγματοληψίας του διακομιστή JACK</translation>
    </message>
    <message>
        <source>ALSA</source>
        <translation></translation>
    </message>
    <message>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation>Μην χρησιμοποιείται πολύ μεγάλο ρυθμό δειγματοληψίας. Τα 22050Hz πρέπει να είναι αρκετά στις περισσότερες περιπτώσεις.</translation>
    </message>
    <message>
        <source>The name of the OSS device to connect to</source>
        <translation>Το όνομα της συσκευής OSS με την οποία θα γίνει σύνδεση</translation>
    </message>
    <message>
        <source>The name of the PortAudio device to connect to</source>
        <translation>Το όνομα της συσκευής PortAudio με την οποία θα γίνει σύνδεση</translation>
    </message>
    <message>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation>Παραλληλόγραμο φίλτρο: κακή ακρίβεια, αλλά πολύ γρήγορο</translation>
    </message>
    <message>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation>Φίλτρο FIR: καλή ακρίβεια, αλλά χρησιμοποιεί περισσότερο την CPU</translation>
    </message>
    <message>
        <source>Algorithm settings</source>
        <translation>Ρυθμίσεις αλγόριθμου</translation>
    </message>
    <message>
        <source> dB</source>
        <translation> dB</translation>
    </message>
    <message>
        <source>Use sub-harmonic audibility threshold</source>
        <translation>Χρήση ηχητικού κατωφλίου υπο-αρμονικών</translation>
    </message>
    <message>
        <source>Window size factor</source>
        <translation>Συντελεστής μεγέθους παραθύρου</translation>
    </message>
    <message>
        <source>Frequency refinement settings</source>
        <translation>Ρυθμίσεις βελτίωσης συχνότητας</translation>
    </message>
    <message>
        <source>Frequency domain fundamental refinement:
mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation>Θεμελιώδης βελτίωση στο πεδίο συχνότητας:
μέσος των θεμελιωδών σχετικών συχνοτήτων των αρμονικών.
Επιλέξτε τον αριθμό των αρμονικών που θα χρησιμοποιηθούν.</translation>
    </message>
    <message>
        <source>Quantizer settings</source>
        <translation>Ρυθμίσεις κβαντιστή</translation>
    </message>
    <message>
        <source>Restore &amp;factory settings</source>
        <translation>Επαναφορά στις εργοστασιακές ρυθμίσεις</translation>
    </message>
    <message>
        <source>Raise the window to the whole screen when the program is started
(You can also use the shortcut &apos;f&apos;).</source>
        <translation>Ανάπτυξη του παραθύρου σε ολόκληρη την οθόνη όταν το πρόγραμμα ξεκινά (Μπορείτε επίσης να χρησιμοποιήσετε την συντόμευση &apos;f&apos;).</translation>
    </message>
    <message>
        <source>Auto-save configuration and layout on exit</source>
        <translation>Αυτόματη αποθήκευση διαμόρφωσης και διάταξης κατά την έξοδο</translation>
    </message>
    <message>
        <source>The used tuning scale to determine note frequency values. Useful for tuning historic intruments.</source>
        <translation>Η χρησιμοποιημένη κλίμακα συντονισμού που καθορίζει τις τιμές συχνοτήτων νότας. Χρήσιμο για συντονισμό ιστορικών οργάνων.</translation>
    </message>
    <message>
        <source>The used tonality.
Useful to convert note names to a corresponding instrument tonality (e.g. Eb for saxophone, Bb for trumpet).</source>
        <translation type="vanished">Η χρησιμοποιημένη τονικότητα.
Χρήσιμο στην μετατροπή ονομάτων από νότες σε αντίστοιχη τονικότητα οργάνου (π.χ. Eb για σαξόφωνο, Bb για τρομπέτα).</translation>
    </message>
    <message>
        <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Επιλεγμένο σύστημα σύλληψης (π.χ. JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <source>Auto detect a working capture system at FMIT startup.</source>
        <translation>Αυτόματη αναγνώριση ενός λειτουργικού συστήματος σύλληψης κατά την εκκίνηση του FMIT.</translation>
    </message>
    <message>
        <source>The name of this FMIT instance in the JACK connections.</source>
        <translation>Το όνομα αυτής της διεργασίας FMIT στις συνδέσεις του JACK.</translation>
    </message>
    <message>
        <source>Automatically connect FMIT to the following source at startup (e.g. alsa_pcm:capture_1)</source>
        <translation>Αυτόματη σύνδεση του FMIT στην ακόλουθη πηγή κατά την εκκίνηση (π.χ. alsa_pcm:capture_1)</translation>
    </message>
    <message>
        <source>automaticaly connect to...</source>
        <translation>αυτόματη σύνδεση σε...</translation>
    </message>
    <message>
        <source>JACK sampling rate</source>
        <translation>Ρυθμός δειγματοληψίας JACK</translation>
    </message>
    <message>
        <source>The name of the ALSA device to use.</source>
        <translation>Το όνομα της συσκευής ALSA που θα χρησιμοποιηθεί.</translation>
    </message>
    <message>
        <source>The chosen sampling rate.
Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
        <translation>Ο επιλεγμένος ρυθμός δειγματοληψίας.
Μην χρησιμοποιείτε πολύ μεγάλο ρυθμό δειγματοληψίας. Το 22050Hz πρέπει να είναι αρκετό στις περισσότερες περιπτώσεις.</translation>
    </message>
    <message>
        <source>Set the sampling rate to the maximum possible value.</source>
        <translation>Ορισμός του ρυθμού δειγματοληψίας στην μεγαλύτερη δυνατή τιμή.</translation>
    </message>
    <message>
        <source>Mix channels if there are multiple (if unchecked, the first channel will be used)</source>
        <translation>Ανάμιξη των καναλιών αν υπάρχουν πολλαπλά (αν δεν είναι επιλεγμένο, το πρώτο κανάλι θα χρησιμοποιηθεί)</translation>
    </message>
    <message>
        <source>Time between each sound analysis.
Can be increased to get less CPU usage (but less temporal precision).</source>
        <translation>Χρόνος μεταξύ κάθε ανάλυσης ήχου.
Μπορεί να αυξηθεί για να χρησιμοποιείται λιγότερη η CPU (αλλά με λιγότερη προσωρινή ακρίβεια).</translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the A4 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation type="vanished">Εύρος από πιθανές νότες, από την χαμηλότερη στην υψηλότερη γύρω από την νότα αναφοράς Α4.
Μικρότερο εύρος αντιστοιχεί σε μικρότερη χρήση CPU.</translation>
    </message>
    <message>
        <source>Notes range</source>
        <translation>Εύρος από νότες</translation>
    </message>
    <message>
        <source>Lowest semitone from the A4 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation type="vanished">Χαμηλότερο ημιτόνιο από την νότα αναφοράς Α4.
Μπορεί να είναι χρήσιμο να είναι υψηλότερο από -35 για αποφυγή διαταραχής από τροφοδοσία τομέα (~50Hz).</translation>
    </message>
    <message>
        <source>Highest semitone from the A4 reference note.</source>
        <translation type="vanished">Υψηλότερο ημιτόνιο από την νότα αναφοράς Α4.</translation>
    </message>
    <message>
        <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
        <translation>Φιλτράρισμα ήχου κάτω από το χαμηλότερο ημιτόνιο και πάνω από το υψηλότερο ημιτόνιο, για αποφυγή τεχνουθργημάτων και θορύβων σε όλα τα ακόλουθα στάδια της ανάλυσης ήχου.</translation>
    </message>
    <message>
        <source>Notes range filtering</source>
        <translation>Φιλτράρισμα εύρους από νότες</translation>
    </message>
    <message>
        <source>Ignore all sounds with volume below this threshold [dB]
(Shown as a red line in various views)</source>
        <translation>Αγνόηση όλων των ήχων με ένταση κάτω από αυτό το κατώφλι [dB].
(Εμφανίζεται ως κόκκινη γραμμή σε διάφορες προβολές)</translation>
    </message>
    <message>
        <source>Ignore weak sub-harmonics.
This threshold is defined between two neighbors frequency components.
Prevents underestimation errors.</source>
        <translation>Αγνόηση αδύναμων υπο-αρμονικών.
Αυτό το κατώφλι ορίζεται μεταξύ δύο γειτονικών συστατικών συχνότητας.</translation>
    </message>
    <message>
        <source>Factor defining the window size (from the lowest possible period defined by the notes range).
The bigger this factor, the more stable the analysis. However, by increasing this factor, FMIT will need more CPU and will react slower to sound changes.</source>
        <translation>Συντελεστής που ορίζει το μέγεθος παραθύρου (από την χαμηλότερη δυνατή περίοδο που ορίζεται από το εύρος που έχουν οι νότες).
Όσο μεγαλύτερος είναι αυτός ο συντελεστής, τόσο πιο σταθερή η ανάλυση. Πάντως, αυξάνοντας αυτό τον συντελεστή, το FMIT θα χρειάζεται περισσότερη CPU και θα αντιδρά πιο αργά στις αλλαγές του ήχου.</translation>
    </message>
    <message>
        <source>Use a refinement method in frequency domain: compute the mean of the quasi-harmonic related spectral peaks (the option allows to chose the number of harmonics to use).</source>
        <translation>Χρήση μεθόδου βελτίωσης στο πεδίο συχνότητας: υπολογισμός του μέσου των φασματικών κορυφών που σχετίζονται με τις αρμονικές (η επιλογή επιτρέπει την επιλογή του αριθμού των αρμονικών που θα χρησιμοποιηθούν).</translation>
    </message>
    <message>
        <source>Use a refinement method in time domain: compute the mean of various period lengths (the option allows to chose the number of periods to use).</source>
        <translation>Χρήση μεθόδου βελτίωσης στο πεδίο χρόνου: υπολογισμός του μέσου από μήκη διαφόρων περιόδων (επιτρέπει την επιλογή του αριθμού περιόδων που θα χρησιμοποιηθούν).</translation>
    </message>
    <message>
        <source>Quantize the analysis results: ignore frequency jumps, fill gaps, ignore short notes.
The smaller the value, the faster the tuner. However, by decreasing the value, the computed frequency will be more unstable.</source>
        <translation>Κβαντισμός των αποτελεσμάτων ανάλυσης: αγνόηση αλμάτων συχνότητας, γέμισμα κενών, αγνόηση σύντομης νότας.
Όσο μικρότερη είναι η τιμή, τόσο γρηγορότερος είναι ο συντονισμός. Πάντως, μειώνοντας την τιμή, η υπολογισμένη συχνότητα θα είναι περισσότερο ασταθής.</translation>
    </message>
    <message>
        <source>Restore settings as if you just installed FMIT (requires to restart FMIT).</source>
        <translation>Επαναφορά ρυθμίσεων, σαν να εγκαταστήσατε μόλις τώρα το FMIT (απαιτεί επανεκκίνηση του FMIT).</translation>
    </message>
    <message>
        <source>Use these settings and quit the configuration panel (it is required to click on the &quot;Save settings&quot; button to permanently keep these settings for each FMIT start)</source>
        <translation>Χρήση αυτών των ρυθμίσεων και εγκατάλειψη του παραθύρου διαμόρφωσης (απαιτείται να πατήσετε στο κουμπί &quot;Αποθήκευση ρυθμίσεων&quot; για να κρατήσετε μόνιμα αυτές τις ρυθμίσεις σε κάθε εκκίνηση του FMIT)</translation>
    </message>
    <message>
        <source>Discard any changes and quit the configuration panel</source>
        <translation>Απόρριψη οποιονδήποτε αλλαγών και εγκατάλειψη του παραθύρου διαμόρφωσης</translation>
    </message>
    <message>
        <source>The capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Το σύστημα σύλληψης (π.χ. JACK, ALSA OSS, PortAudio)</translation>
    </message>
    <message>
        <source>The capture system</source>
        <translation>Το σύστημα σύλληψης</translation>
    </message>
    <message>
        <source>Chromatic</source>
        <translation>Χρωματική</translation>
    </message>
    <message>
        <source>Diatonic</source>
        <translation>Διατονική</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Για περισσότερες επιλογές, κάντε δεξί κλικ σε κάθε προβολή για να εμφανιστούν οι ιδιότητες τους!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Γερμανικά</translation>
    </message>
    <message>
        <source>Use localized note names. e.g.:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation>Χρήση τοπικοποιημένων ονομάτων νοτών. π.χ.:
αγγλο-σαξονικό: C D E F G A B
λατινικό: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <source>Hindustani</source>
        <translation>Ινδουστανική</translation>
    </message>
    <message>
        <source>Byzantine</source>
        <translation>Βυζαντινή</translation>
    </message>
    <message>
        <source>Transposition</source>
        <translation>Μετατόπιση</translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <source>Restore Factory Settings</source>
        <translation>Επαναφορά στις εργοστασιακές ρυθμίσεις</translation>
    </message>
    <message>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Αυτή η λειτουργία ΔΕΝ είναι αναστρέψιμη.
Είστε σίγουροι ότι θέλετε να χάσετε όλες τις τρέχουσες ρυθμίσεις σας;</translation>
    </message>
    <message>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Μπορείτε τώρα να επανεκινήσετε το FMIT για να επιστρέψετε στις εργοστασιακές ρυθμίσεις</translation>
    </message>
    <message>
        <source>The base tunning frequency (the %1 frequency)</source>
        <translation>Η βασική συχνότητα συντονισμού (η συχνότητα %1)</translation>
    </message>
    <message>
        <source>Allows to add an offset to the reference %1</source>
        <translation>Επιτρέπει να προστεθεί μια μετατόπιση στην αναφορά %1</translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation>Εύρος από πιθανές νότες, από την χαμηλότερη στην υψηλότερη γύρω από την νότα αναφοράς %1.
Μικρότερο εύρος αντιστοιχεί σε μικρότερη χρήση CPU.</translation>
    </message>
    <message>
        <source>Lowest semitone from the %1 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation>Χαμηλότερο ημιτόνιο από την νότα αναφοράς %1.
Μπορεί να είναι χρήσιμο να είναι υψηλότερο από -35 για αποφυγή διαταραχής από τροφοδοσία τομέα (~50Hz).</translation>
    </message>
    <message>
        <source>Highest semitone from the %1 reference note.</source>
        <translation>Υψηλότερο ημιτόνιο από την νότα αναφοράς %1.</translation>
    </message>
    <message>
        <source>Transposition in number of semitones relative to %1.
Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
        <translation>Μετατόπιση σε αριθμό ημιτονίων σε σχέση με %1.
Χρήσιμο για τη μετατροπή ονομάτων νοτών σε αντίστοιχο όργανο μετατόπισης (π.χ. %2 για σαξόφωνο, %3 για τρομπέτα).</translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <source>Show trace</source>
        <translation>Εμφάνιση ίχνους</translation>
    </message>
    <message>
        <source>Show tolerance</source>
        <translation>Εμφάνιση ανοχής</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Χρήση εκατοστών</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Εύρος κλίμακας</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Εύρος κλίμακας (σε εκατοστά)</translation>
    </message>
    <message>
        <source>Dial</source>
        <translation>Καντράν</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Keep previous notes</source>
        <translation>Διατήρηση προηγούμενων νότων</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Χρήση εκατοστών</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Εύρος κλίμακας</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Εύρος κλίμακας (σε εκατοστά)</translation>
    </message>
    <message>
        <source>Error history</source>
        <translation>Ιστορικό σφαλμάτων</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <source>Fourier Transform</source>
        <translation>Μετασχηματισμός Fourier</translation>
    </message>
    <message>
        <source>dB scale</source>
        <translation>κλίμακα dB</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <source>window length</source>
        <translation>μήκος παραθύρου</translation>
    </message>
    <message>
        <source>- Press left mouse button to move the view</source>
        <translation>- Πατήστε το αριστερό πλήκτρο του ποντικιού για να μετακινήσετε την προβολή</translation>
    </message>
    <message>
        <source>- Press SHIFT key and left mouse button to zoom in and out</source>
        <translation>- Πατήστε το πλήκτρο SHIFT και το αριστερό πλήκτρο του ποντικιού για μεγέθυνση ή σμίκρυνση</translation>
    </message>
    <message>
        <source>- Double-click to reset the view</source>
        <translation>- Διπλό κλικ για επαναφορά της προβολής</translation>
    </message>
    <message>
        <source>Frequency %1 [Hz]</source>
        <translation>Συχνότητα %1 [Hz]</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <source>Number of harmonics</source>
        <translation>Αριθμός αρμονικών</translation>
    </message>
    <message>
        <source>Harmonics</source>
        <translation>Αρμονικές</translation>
    </message>
    <message>
        <source>Harmonics&apos; amplitude</source>
        <translation>Πλάτος αρμονικών</translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <source>Captured Sound</source>
        <translation>Είσοδος ήχου</translation>
    </message>
    <message>
        <source>Auto scale</source>
        <translation>Αυτόματη κλίμακα</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <source>Max height</source>
        <translation>Μέγιστο ύψος</translation>
    </message>
    <message>
        <source>Show Wave Form</source>
        <translation>Εμφάνιση κυματομορφής</translation>
    </message>
    <message>
        <source>Scale factor</source>
        <translation>Συντελεστής κλίμακας</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <source>Show fading</source>
        <translation>Εμφάνιση εξασθένησης</translation>
    </message>
    <message>
        <source>Number of fading</source>
        <translation>Αριθμός εξασθένησης</translation>
    </message>
    <message>
        <source>Waveform</source>
        <translation>Κυματομορφή</translation>
    </message>
    <message>
        <source>Waveform&apos;s period</source>
        <translation>Περίοδος κυματομορφής</translation>
    </message>
</context>
<context>
    <name>GLStatistics</name>
    <message>
        <source>Statistics</source>
        <translation>Στατιστικά</translation>
    </message>
    <message>
        <source>Reset statistics</source>
        <translation>Επαναφορά στατιστικών</translation>
    </message>
    <message>
        <source>Keep notes when hidden</source>
        <translation>Διατήρηση νότων στην απόκρυψη</translation>
    </message>
    <message>
        <source>Keep n values</source>
        <translation>Διατήρηση n τιμών</translation>
    </message>
    <message>
        <source>Keep this number of values in the computation of the statistics</source>
        <translation>Διατήρηση αυτό τον αριθμό τιμών στον υπολογισμό των στατιστικών</translation>
    </message>
    <message>
        <source>Show standard deviation</source>
        <translation>Εμφάνιση τυπικής απόκλισης</translation>
    </message>
    <message>
        <source>Scale auto</source>
        <translation>Αυτόματη κλίμακα</translation>
    </message>
    <message>
        <source>Scale min</source>
        <translation>Ελάχιστο κλίμακας</translation>
    </message>
    <message>
        <source>Scale min value (in semi-tones)</source>
        <translation>Ελάχιστη τιμή της κλίμακας (σε ημιτόνια)</translation>
    </message>
    <message>
        <source>Scale max</source>
        <translation>Μέγιστο κλίμακας</translation>
    </message>
    <message>
        <source>Scale max value (in semi-tones)</source>
        <translation>Μέγιστη τιμή κλίμακας (σε ημιτόνια)</translation>
    </message>
    <message>
        <source>Show tolerance</source>
        <translation>Εμφάνιση ανοχής</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Χρήση εκατοστών</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Échelle d&apos;étirement</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Εύρος κλίμακας (σε εκατοστά)</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <source>Keep previous notes</source>
        <translation>Διατήρηση προηγούμενων νότων</translation>
    </message>
    <message>
        <source>Volume history</source>
        <translation>Ιστορικό έντασης</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Ένταση</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <source>K
e
e
p</source>
        <translation>Δ
ι
α
τ
ή
ρ
η
σ
η</translation>
    </message>
    <message>
        <source>K</source>
        <translation>Δ</translation>
    </message>
    <message>
        <source>Note Stability</source>
        <translation>Σταθερότητα νότας</translation>
    </message>
    <message>
        <source>Tuning Frequency</source>
        <translation>Συχνότητα συντονισμού</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Κενό</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <source>Save settings</source>
        <translation>Εμφάνιση ρυθμίσεων</translation>
    </message>
    <message>
        <source>Views</source>
        <translation>Προβολές</translation>
    </message>
    <message>
        <source>The recognized note</source>
        <translation>Η αναγνωρισμένη νότα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Μετατόπιση</translation>
    </message>
    <message>
        <source> cents</source>
        <translation> εκατοστά</translation>
    </message>
    <message>
        <source>Free Music Instrument Tuner</source>
        <translation></translation>
    </message>
    <message>
        <source> Hz</source>
        <translation></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Keep the data in the error and volume views (shortcut &quot;k&quot;).</source>
        <translation>Διατήρηση των δεδομένων στις προβολές σφαλμάτων και έντασης (συντόμευση &quot;δ&quot;).</translation>
    </message>
    <message>
        <source>Volume in dB.
Computed in the frequency domain, from the maximum bin.
The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
        <translation>Ένταση σε dB.
Υπολογισμένη στο πεδίο συχνότητας, από την ομάδα των μέγιστων.
Το μέγιστο επιτυγχάνεται όταν η ενέργεια του σήματος είναι μέγιστη και ΌΧΙ όταν ο ήχος είναι κορεσμένος στο πεδίο του χρόνου.</translation>
    </message>
    <message>
        <source>According to the following colors:
red       : the capture system is not working.
grey     : the capture system is OK, but there is not enough sound.
orange : the analysis conditions are bad (like saturation)
green   : a note is beeing analyzed and analysis conditions are OK.</source>
        <translation>Σύμφωνα με τα παρακάτω χρώματα:
κόκινο    : το σύστημα σύλληψης δεν λειτουργεί.
γκρι      : το σύστημα σύλληψης είναι εντάξει, αλλά δεν υπάρχει αρκετός ήχος.
πορτοκαλί : οι συνθήκες ανάλυσης είναι κακές (όπως ο κορεσμός).
πράσινο   : μία νότα αναλύεται τώρα και οι συνθήκες ανάλυσης είναι καλές.</translation>
    </message>
    <message>
        <source>The base tunning frequency (the A4 frequency)</source>
        <translation>Η βασική συχνότητα συντονισμού (η συχνότητα Α4)</translation>
    </message>
    <message>
        <source>Offset in cents from the base tuning frequency</source>
        <translation>Μετατόπιση σε εκατοστά από την βασική συχνότητα συντονισμού</translation>
    </message>
    <message>
        <source>The frequency of the current note in Hertz.</source>
        <translation>Η συχνότητα της τρέχουσας νότας σε Hertz.</translation>
    </message>
    <message>
        <source>The target frequency of the current note in Hertz.</source>
        <translation>Η επιθυμητή συχνότητα της τρέχουσας νότας σε Hertz.</translation>
    </message>
    <message>
        <source>Pause: the capture, the sound analysis and all views.</source>
        <translation>Παύση: η σύλληψη, η ανάλυση ήχου και όλες οι προβολές.</translation>
    </message>
    <message>
        <source>Save configuration panel settings, views settings and the window size.</source>
        <translation>Αποθήκευση διαμόρφωσης των ρυθμίσεων πλαισίων, ρυθμίσεων προβολών και μέγεθος παραθύρου.</translation>
    </message>
    <message>
        <source>Invoke the about box.</source>
        <translation>Επίκληση του παραθύρου Σχετικά.</translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <source>Unkown filename: &apos;</source>
        <translation>Άγνωστο όνομα αρχείου: &apos;</translation>
    </message>
    <message>
        <source>Keep root to left side</source>
        <translation>Διατήρηση αρχικής στην αριστερή πλευρά</translation>
    </message>
    <message>
        <source>Load Scala file ...</source>
        <translation>Φόρτωση αρχείου κλίμακας ...</translation>
    </message>
    <message>
        <source>Open scale file</source>
        <translation>Άνοιγμα αρχείου κλίμακας</translation>
    </message>
    <message>
        <source>Scale name already exist</source>
        <translation>Το όνομα της κλίμακας ήδη υπάρχει</translation>
    </message>
    <message>
        <source>Invalid file content !</source>
        <translation>Άκυρο περιεχόμενο αρχείου !</translation>
    </message>
    <message>
        <source>Root&apos;s octave</source>
        <translation>Αρχική οκτάβα</translation>
    </message>
    <message>
        <source>Microtonal</source>
        <translation>Μικροτονική</translation>
    </message>
    <message>
        <source>Used scale</source>
        <translation>Χρησιμοποιηθείσα κλίμακα</translation>
    </message>
    <message>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation>&lt;b&gt;όνομα:&lt;/b&gt; </translation>
    </message>
    <message>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation>&lt;b&gt;αριθμός αναλογίας:&lt;/b&gt; </translation>
    </message>
    <message>
        <source>Invalid Scala file: </source>
        <translation>Άκυρο αρχείο κλίμακας: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>default</source>
        <translation>προεπιλογή</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
